# Canvas

Canvas commands are used to create, position, and modify canvas objects. The Canvas commands need only the abaqus module to be imported; no additional modules need to be imported.

## Create layers in a viewport

### Viewport

```{eval-rst}
.. autoclass:: abaqus.Canvas.Viewport.Viewport
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Other Classes

```{eval-rst}

.. toggle::

    .. automembers:: abaqus.Annotation
        :recursive:
        :exclude: Viewport
```
